import React, { Component } from "react";
import { connect } from "react-redux";
import { reduxForm, Field, FieldArray } from "redux-form";

import { renderField } from "../common/formFunc";

const ololo = values => {
	const { origin, destination } = values;

	const errors = {};
	if (!origin) {
		errors.origin = "Required";
	}
	if (!destination) {
		errors.destination = "Required";
	}

	return errors;
};

const renderHobbies = ({ fields, meta: { error } }) => {
	// console.log(fields);
	return (
		<ul>
			<li>
				<button type="button" onClick={() => fields.push()}>
					Добавить груз
				</button>
			</li>

			{fields.map((el, index) => (
				<li key={index}>
					<button type="button" title="Remove Hobby" onClick={() => fields.remove(index)}>
						x
					</button>

					<Field name={`${el}.name`} label="Груз" type="text" component={renderField} />
				</li>
			))}
			{error && <li className="error">{error}</li>}
		</ul>
	);
};

class LoadForm extends Component {
	changeHandler = e => {
		const { changeInputValue } = this.props;
		const { value, id, checked } = e.target;
		changeInputValue({ value, id, checked });
	};

	submit = values => {
		const { event } = this.props;

		event(values);
	};

	render() {
		const { handleSubmit, title, pristine, submitting } = this.props;

		return (
			<form onSubmit={handleSubmit(this.submit)} className="form">
				<Field name="origin" label="Город отправитель" type="text" component={renderField} />
				<Field name="destination" label="Город получатель" type="text" component={renderField} />
				<Field name="contactName" label="Введите имя водителя" type="text" component={renderField} />
				<Field name="night" label="Ночная перевозка ?" type="checkbox" component={renderField} />

				<div className="form__input-box">
					<label className="form__input-lable" htmlFor="bodyType">
						Тип кузова
						<Field name="bodyType" component="select">
							<option value="type1">Тип 1</option>
							<option value="type2">Тип 2</option>
							<option value="type3">Тип 3</option>
							<option value="type4">Тип 4</option>
						</Field>
					</label>
				</div>

				<Field name="weight" label="Вес" type="number" component={renderField} />

				<FieldArray name="loads" component={renderHobbies} />

				<div className="form__button-box">
					<button
						disabled={pristine || submitting}
						style={{ color: pristine || submitting ? "red" : "black" }}
						className="form__submit-button">
						{title}
					</button>
					<button type="button" className="form__submit-button form__submit-button--reset">
						Очистить форму
					</button>
				</div>
			</form>
		);
	}
}

const mapStateToProps = (state, props) => ({
	form: props.formId
});

const component = reduxForm({ validate: ololo, enableReinitialize: true })(LoadForm);

export default connect(mapStateToProps)(component);
