import React, { Component, Fragment } from "react";
import { bindActionCreators } from "redux";
import { connect } from "react-redux";

import * as actions from "../actions/todo";
import List from "../components/list";
import LoadForm from "../components/loadForm";
import EditModal from "../components/modal";

import { auth, googleAuthProvider } from "../firebaseConfig";

class App extends Component {
	state = {
		openAddForm: false,
		toggleModal: false,
		user: null
	};

	componentDidMount() {
		const { getLoads } = this.props;

		getLoads();

		auth.onAuthStateChanged(user => this.setState({ user }));
	}

	authRequest = () => {
		auth.signInWithPopup(googleAuthProvider).then(res => this.setState({ user: res.user }));
	};

	openEditModal = id => {
		const { getInitVal } = this.props;
		getInitVal(id);
		this.setState({ toggleModal: true, openAddForm: false });
	};
	closeEditModal = () => this.setState({ toggleModal: false });

	openFormHandler = () => this.setState(prevState => ({ openAddForm: !prevState.openAddForm }));

	render() {
		const { list, inputData, editLoadsRequest, initialValues, postLoads } = this.props;
		const { openAddForm, toggleModal, user } = this.state;
		return (
			<Fragment>
				<button onClick={this.authRequest}>Auth</button>

				<h1>{user && user.displayName}</h1>

				<h1 className="h1-tag">
					Доставка грузов "to-do list" -{" "}
					<span onClick={this.openFormHandler} className="h1-tag h1-tag--add">
						Добавить груз
					</span>
				</h1>
				<div className="todo">
					<List list={list} openEditModal={this.openEditModal} />

					<div style={{ width: `50%` }}>
						{openAddForm && (
							<LoadForm formId="addLoads" title="Создать доставку" event={postLoads} inputData={inputData} />
						)}
					</div>
				</div>

				<EditModal
					initialValues={initialValues}
					editLoads={editLoadsRequest}
					inputData={inputData}
					visible={toggleModal}
					handleClose={this.closeEditModal}
				/>
			</Fragment>
		);
	}
}

const mapStateToProps = state => ({
	list: state.todo.list,
	inputData: state.todo.data,
	initialValues: state.todo.initialValues
});

const mapDispatchToProps = dispatch => bindActionCreators({ ...actions }, dispatch);

export default connect(
	mapStateToProps,
	mapDispatchToProps
)(App);
